determines if/how census tract boundaries changed from 2010 to 2020. Adds an additional "type_change" column to 2010-2020 tract relationship file indicating whether a tract did not change ("same"), a tract was split but bounds did not change ("split"), or a tracts bounds moved ("moved"). param: res(character - default "tract") -> resolution to get changes for. param: geoids(character vector - default NULL) -> geoids to get changes for. if none provided, returns all of US return: dataframe of relationship data with "type_change" column.
get_2010_2020_bound_changes.Rddetermines if/how census tract boundaries changed from 2010 to 2020. Adds an additional "type_change" column to 2010-2020 tract relationship file indicating whether a tract did not change ("same"), a tract was split but bounds did not change ("split"), or a tracts bounds moved ("moved"). param: res(character - default "tract") -> resolution to get changes for. param: geoids(character vector - default NULL) -> geoids to get changes for. if none provided, returns all of US return: dataframe of relationship data with "type_change" column.